@@ -414,7 +414,7 @@ do														\
 	THIS_SHOULD_NEVER_HAPPEN;										\
 	zbx_error(fmt, ##__VA_ARGS__);										\
 }														\
-while(0)
+while (0)
 
 #define ARRSIZE(a)	(sizeof(a) / sizeof(*a))
 
@@ -681,7 +681,7 @@ int	zbx_alarm_timed_out(void);
 #define ZBX_PREPROC_FAIL_SET_VALUE	2
 #define ZBX_PREPROC_FAIL_SET_ERROR	3
 
-
+#define ZBX_SHA512_BINARY_LENGTH 64
 
 /* includes terminating '\0' */
 #define CUID_LEN	26
@@ -764,7 +764,7 @@ static	type2	get_##varname(void) \
 typedef void (*zbx_log_func_t)(int level, const char *fmt, va_list args);
 
 void	zbx_init_library_common(zbx_log_func_t log_func, zbx_get_progname_f get_progname, zbx_backtrace_f backtrace);
-void	zbx_log_handle(int level, const char *fmt, ...);
+void	zbx_log_handle(int level, const char *fmt, ...) __zbx_attr_format_printf(2, 3);
 int	zbx_get_log_level(void);
 void	zbx_set_log_level(int level);
 const char	*zbx_get_log_component_name(void);
@@ -784,6 +784,7 @@ zbx_log_component_t;
 
 void	zbx_set_log_component(const char *name, zbx_log_component_t *component);
 void	zbx_change_component_log_level(zbx_log_component_t *component, int direction);
+void	zbx_malloc_trim(time_t now, int period, size_t pad);
 #endif
 
 #endif
